#!/usr/bin/env ruby
# 
# Copyright (C) 2007 by Levi Bard
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
# 
# @author Levi Bard <taktaktaktaktaktaktaktaktaktak@gmail.com>
# 


require 'lightmediascanner'

if(__FILE__ == $0)
	require 'test/unit'

	# Test cases for LightMediaScanner.  You probably don't care about this.
	class LightMediaScanner::Test < Test::Unit::TestCase
		include LightMediaScanner

		def test_module()
			assert(LightMediaScanner::constants.include?('Scanner'))
			assert(LightMediaScanner::constants.include?('Parser'))
		end

		def test_scanner_gooddata()
			dbPath = '/'
			timeout = 60000
			commitInterval = 1000

			lms = nil
			assert_nothing_raised(){ lms = Scanner.new(dbPath) }
			assert_equal(dbPath, lms.db_path)

			lms.timeout=timeout
			assert_equal(lms.timeout, timeout)

			assert(!lms.processing?)

			lms.commit_interval = commitInterval
			assert_equal(lms.commit_interval, commitInterval)

			assert_raise(RuntimeError){ lms.process('/') }
			assert_raise(RuntimeError){ lms.check('/') }
			assert_nothing_raised(){ lms.add_charset('ISO-8859-1') }
			assert_nothing_raised(){ lms.remove_charset('ISO-8859-1') }
			assert_raise(RuntimeError){ Parser.new(lms, 'blah') }
		end

		def test_scanner_baddata()
			dbPath = '/'
			timeout = 60000
			commitInterval = 1000

			lms = nil
			assert_raise(TypeError){ lms = Scanner.new(nil) }
			assert_nothing_raised(){ lms = Scanner.new(dbPath) }
			assert_equal(dbPath, lms.db_path)

			assert_raise(TypeError){ lms.timeout = 'Jared' }
			assert_raise(TypeError){ lms.timeout = 3.14159 }

			assert_raise(TypeError){ lms.commit_interval = 2.72 }
			assert_raise(TypeError){ lms.commit_interval = nil }

			assert_raise(TypeError){ lms.process(nil) }
			assert_raise(TypeError){ lms.process(3) }

			assert_raise(TypeError){ lms.check(lms) }
			assert_raise(TypeError){ lms.check(5.43) }

			assert_raise(TypeError){ lms.add_charset(nil) }
			assert_raise(TypeError){ lms.add_charset(42) }
			assert_raise(RuntimeError){ lms.add_charset('I CAN HAZ CHARSET?') }

			assert_raise(RuntimeError){ lms.remove_charset('EBCDIC') }
			assert_raise(TypeError){ lms.remove_charset(nil) }
		end
	end
end
